@@ -368,7 +368,7 @@ async def mythic_service(debug: bool):
                 task4 = asyncio.ensure_future(connect_and_consume_rpc(main_config))
                 if debug:
                     print_flush("Waiting for all tasks to finish in mythic_service")
-                result = await asyncio.wait_for(task, task4)
+                result = await asyncio.gather(task, task4)
                 if debug:
                     print_flush("All tasks finished in mythic_service, repeating loop")
             except Exception as e:
